# _DBT_PKG_NAME_
A dbt package generated by [Reflekt](https://github.com/GClunies/reflekt) that includes sources, models, and docs for events from tracking plan(s) found in _PLAN_TOOL_.

To use this package, add it to the `packages.yml` of your dbt project.

```yaml
  # Example packages.yml in dbt project
  packages:
  - package: dbt-labs/dbt_utils
    version: 0.8.5

  - git: "https://github.com/<YOUR-USER-ORG>/<YOUR-REPO>"  # Replace with your repo URL
    subdirectory: "dbt-packages/_DBT_PKG_NAME_"
    revision: v0.1.0___DBT_PKG_NAME_  # Example tag. Replace with your branch, tag, or commit (full 40-character hash)
  ```

### Reflekt resources:
- [GitHub repo](https://github.com/GClunies/Reflekt)
- [Reflekt Docs](https://reflekt-ci.notion.site/reflekt-ci/Reflekt-Docs-a27c2dd7006b4584b6a451819b09cdb7)

### dbt resources:
- dbt [docs](https://docs.getdbt.com/docs/introduction)
- Docs on dbt [packages](https://docs.getdbt.com/docs/building-a-dbt-project/package-management/)
- dbt [slack & discourse communities](https://community.getdbt.com/)
- dbt [blog](https://blog.getdbt.com/)
